@@ -655,6 +655,12 @@ class Aggregation(Hirarchy):
 
     @property
     def parent_connection(self) -> int:
+        """
+        AGGREGATION = 1
+        INHERITANCE = 2
+        AGGREGATION+INHERITANCE =3
+        :return:
+        """
         return self.parent.connection_dict[self]
 
     def add_child(self, child: Aggregation, connection_type: int = constants.AGGREGATION) -> Aggregation:
